@@ -23,7 +23,7 @@
 ** TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 ** SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
-#define PJ_LIB__
+#define PJ_LIB_
 
 #include <math.h>
 #include <stdlib.h>
@@ -44,7 +44,7 @@ struct GAUSS {
 #define DEL_TOL 1e-14
 
 static double srat(double esinp, double ratexp) {
-    return(pow((1.-esinp)/(1.+esinp), ratexp));
+    return (pow((1. - esinp) / (1. + esinp), ratexp));
 }
 
 void *pj_gauss_ini(double e, double phi0, double *chi, double *rc) {
@@ -56,7 +56,8 @@ void *pj_gauss_ini(double e, double phi0, double *chi, double *rc) {
     es = e * e;
     en->e = e;
     sphi = sin(phi0);
-    cphi = cos(phi0);  cphi *= cphi;
+    cphi = cos(phi0);
+    cphi *= cphi;
     *rc = sqrt(1. - es) / (1. - es * sphi * sphi);
     en->C = sqrt(1. + es * cphi * cphi / (1. - es));
     if (en->C == 0.0) {
@@ -70,45 +71,45 @@ void *pj_gauss_ini(double e, double phi0, double *chi, double *rc) {
         free(en);
         return nullptr;
     }
-    if( .5 * phi0 + M_FORTPI < 1e-10 ) {
+    if (.5 * phi0 + M_FORTPI < 1e-10) {
         en->K = 1.0 / srat_val;
-    }
-    else {
-        en->K = tan(.5 * *chi + M_FORTPI) / (
-            pow(tan(.5 * phi0 + M_FORTPI), en->C) *
-            srat_val  );
+    } else {
+        en->K = tan(.5 * *chi + M_FORTPI) /
+                (pow(tan(.5 * phi0 + M_FORTPI), en->C) * srat_val);
     }
     return ((void *)en);
 }
 
-PJ_LP pj_gauss(projCtx ctx, PJ_LP elp, const void *data) {
+PJ_LP pj_gauss(PJ_CONTEXT *ctx, PJ_LP elp, const void *data) {
     const struct GAUSS *en = (const struct GAUSS *)data;
     PJ_LP slp;
-    (void) ctx;
+    (void)ctx;
 
-    slp.phi = 2. * atan( en->K *
-        pow(tan(.5 * elp.phi + M_FORTPI), en->C) *
-        srat(en->e * sin(elp.phi), en->ratexp) ) - M_HALFPI;
+    slp.phi = 2. * atan(en->K * pow(tan(.5 * elp.phi + M_FORTPI), en->C) *
+                        srat(en->e * sin(elp.phi), en->ratexp)) -
+              M_HALFPI;
     slp.lam = en->C * (elp.lam);
-    return(slp);
+    return (slp);
 }
 
-PJ_LP pj_inv_gauss(projCtx ctx, PJ_LP slp, const void *data) {
+PJ_LP pj_inv_gauss(PJ_CONTEXT *ctx, PJ_LP slp, const void *data) {
     const struct GAUSS *en = (const struct GAUSS *)data;
     PJ_LP elp;
     double num;
     int i;
 
     elp.lam = slp.lam / en->C;
-    num = pow(tan(.5 * slp.phi + M_FORTPI)/en->K, 1./en->C);
+    num = pow(tan(.5 * slp.phi + M_FORTPI) / en->K, 1. / en->C);
     for (i = MAX_ITER; i; --i) {
-        elp.phi = 2. * atan(num * srat(en->e * sin(slp.phi), -.5 * en->e))
-            - M_HALFPI;
-        if (fabs(elp.phi - slp.phi) < DEL_TOL) break;
-            slp.phi = elp.phi;
+        elp.phi =
+            2. * atan(num * srat(en->e * sin(slp.phi), -.5 * en->e)) - M_HALFPI;
+        if (fabs(elp.phi - slp.phi) < DEL_TOL)
+            break;
+        slp.phi = elp.phi;
     }
     /* convergence failed */
     if (!i)
-        pj_ctx_set_errno(ctx, PJD_ERR_NON_CONV_INV_MERI_DIST);
+        proj_context_errno_set(
+            ctx, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
     return (elp);
 }
