@@ -227,6 +227,7 @@ DEFINE_WKT_CONSTANT(BASEGEODCRS);
 DEFINE_WKT_CONSTANT(MERIDIAN);
 DEFINE_WKT_CONSTANT(ORDER);
 DEFINE_WKT_CONSTANT(ANCHOR);
+DEFINE_WKT_CONSTANT(ANCHOREPOCH);
 DEFINE_WKT_CONSTANT(CONVERSION);
 DEFINE_WKT_CONSTANT(METHOD);
 DEFINE_WKT_CONSTANT(REMARK);
@@ -278,6 +279,11 @@ DEFINE_WKT_CONSTANT(BASEPARAMCRS);
 DEFINE_WKT_CONSTANT(BASETIMECRS);
 DEFINE_WKT_CONSTANT(VERSION);
 DEFINE_WKT_CONSTANT(GEOIDMODEL);
+DEFINE_WKT_CONSTANT(COORDINATEMETADATA);
+DEFINE_WKT_CONSTANT(EPOCH);
+DEFINE_WKT_CONSTANT(AXISMINVALUE);
+DEFINE_WKT_CONSTANT(AXISMAXVALUE);
+DEFINE_WKT_CONSTANT(RANGEMEANING);
 
 DEFINE_WKT_CONSTANT(GEODETICCRS);
 DEFINE_WKT_CONSTANT(GEODETICDATUM);
@@ -524,6 +530,17 @@ const AxisDirection AxisDirection::UNSPECIFIED("unspecified");
 
 // ---------------------------------------------------------------------------
 
+std::map<std::string, const RangeMeaning *> RangeMeaning::registry;
+
+/** any value between and including minimumValue and maximumValue is valid. */
+const RangeMeaning RangeMeaning::EXACT("exact");
+
+/** Axis is continuous with values wrapping around at the minimumValue and
+ * maximumValue */
+const RangeMeaning RangeMeaning::WRAPAROUND("wraparound");
+
+// ---------------------------------------------------------------------------
+
 //! @cond Doxygen_Suppress
 
 std::map<std::string, const AxisDirectionWKT1 *> AxisDirectionWKT1::registry;
