@@ -1,4 +1,4 @@
-#define PJ_LIB__
+#define PJ_LIB_
 
 #include <math.h>
 
@@ -9,10 +9,9 @@ PROJ_HEAD(fahey, "Fahey") "\n\tPcyl, Sph";
 
 #define TOL 1e-6
 
-
-static PJ_XY s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    (void) P;
+static PJ_XY fahey_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    (void)P;
 
     xy.x = tan(0.5 * lp.phi);
     xy.y = 1.819152 * xy.x;
@@ -20,10 +19,9 @@ static PJ_XY s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
     return xy;
 }
 
-
-static PJ_LP s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse */
-    PJ_LP lp = {0.0,0.0};
-    (void) P;
+static PJ_LP fahey_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
+    PJ_LP lp = {0.0, 0.0};
+    (void)P;
 
     xy.y /= 1.819152;
     lp.phi = 2. * atan(xy.y);
@@ -32,11 +30,10 @@ static PJ_LP s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse */
     return lp;
 }
 
-
 PJ *PROJECTION(fahey) {
     P->es = 0.;
-    P->inv = s_inverse;
-    P->fwd = s_forward;
+    P->inv = fahey_s_inverse;
+    P->fwd = fahey_s_forward;
 
     return P;
 }
